@@ -1,6 +1,6 @@
-#' Probability of not being in ROPE
+#' Probability of being in the ROPE
 #'
-#' Compute the proportion of the posterior distribution that doesn't lie within a region of practical equivalence (ROPE). It is equivalent to running \code{rope(..., ci = 1)}.
+#' Compute the proportion of the whole posterior distribution that doesn't lie within a region of practical equivalence (ROPE). It is equivalent to running \code{rope(..., ci = 1)}.
 #'
 #' @inheritParams rope
 #'
@@ -107,6 +107,8 @@ p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
 #' @export
 p_rope.bcplm <- p_rope.mcmc
 
+#' @export
+p_rope.mcmc.list <- p_rope.mcmc
 
 
 
@@ -121,4 +123,4 @@ p_rope.bcplm <- p_rope.mcmc
 
   class(out) <- c("p_rope", "see_p_rope", "data.frame")
   out
-}
\ No newline at end of file
+}
