@@ -4,9 +4,7 @@ options(knitr.kable.NA = '')
 knitr::opts_chunk$set(comment=">")
 options(digits=2)
 
-if (!(requireNamespace("ggplot2", quietly = TRUE) &&
-      requireNamespace("dplyr", quietly = TRUE)
-      )) {
+if (!requireNamespace("ggplot2", quietly = TRUE) || !requireNamespace("dplyr", quietly = TRUE)) {
   knitr::opts_chunk$set(eval = FALSE)
 }
 
@@ -58,7 +56,7 @@ posterior %>%
   # HDI in blue
   geom_vline(xintercept=ci_hdi$CI_low, color="royalblue", size=3) +
   geom_vline(xintercept=ci_hdi$CI_high, color="royalblue", size=3) +
-  # Quantile in red
+  # ETI in red
   geom_vline(xintercept=ci_eti$CI_low, color="red", size=1) +
   geom_vline(xintercept=ci_eti$CI_high, color="red", size=1)
 
