@@ -1,5 +1,4 @@
 if (require("testthat") && requireNamespace("rstanarm", quietly = TRUE)) {
-
   test_that("map_estimate", {
     testthat::expect_equal(
       as.numeric(map_estimate(distribution_normal(1000))),
@@ -26,12 +25,14 @@ if (require("testthat") && requireNamespace("rstanarm", quietly = TRUE)) {
     test_that("map_estimate", {
       testthat::expect_equal(
         map_estimate(m, effects = "all", component = "all")$Parameter,
-        c("b_Intercept", "b_child", "b_camper", "r_persons.1.Intercept.",
+        c(
+          "b_Intercept", "b_child", "b_camper", "r_persons.1.Intercept.",
           "r_persons.2.Intercept.", "r_persons.3.Intercept.", "r_persons.4.Intercept.",
           "sd_persons__Intercept", "b_zi_Intercept", "b_zi_child", "b_zi_camper",
           "r_persons__zi.1.Intercept.", "r_persons__zi.2.Intercept.", "r_persons__zi.3.Intercept.",
-          "r_persons__zi.4.Intercept.", "sd_persons__zi_Intercept")
+          "r_persons__zi.4.Intercept.", "sd_persons__zi_Intercept"
+        )
       )
     })
   }
-}
\ No newline at end of file
+}
