@@ -1,17 +1,20 @@
 if (require("BayesFactor", quietly = TRUE)) {
-
-
   test_that("weighted_posteriors for BayesFactor", {
     set.seed(123)
     # compute Bayes Factor for 31 different regression models
     null_den <- regressionBF(mpg ~ cyl + disp + hp + drat + wt,
-                             data = mtcars, progress = FALSE)
+      data = mtcars, progress = FALSE
+    )
     wBF <- weighted_posteriors(null_den)
 
     testthat::expect_is(wBF, "data.frame")
-    testthat::expect_equal(attr(wBF, "weights")$weights,
-                           c(0, 13, 9, 0, 0, 55, 11, 4, 4, 1246, 6, 2, 38, 4, 946, 12, 3,
-                             3, 209, 3, 491, 174, 4, 134, 7, 293, 1, 123, 35, 92, 51, 27))
+    testthat::expect_equal(
+      attr(wBF, "weights")$weights,
+      c(
+        0, 13, 9, 0, 0, 55, 11, 4, 4, 1246, 6, 2, 38, 4, 946, 12, 3,
+        3, 209, 3, 491, 174, 4, 134, 7, 293, 1, 123, 35, 92, 51, 27
+      )
+    )
   })
 
   test_that("weighted_posteriors for BayesFactor (intercept)", {
@@ -20,15 +23,17 @@ if (require("BayesFactor", quietly = TRUE)) {
     testthat::skip_on_cran()
     testthat::skip_on_ci()
 
-    dat <- data.frame(x1 = rnorm(10),
-                      x2 = rnorm(10),
-                      y = rnorm(10))
+    dat <- data.frame(
+      x1 = rnorm(10),
+      x2 = rnorm(10),
+      y = rnorm(10)
+    )
     BFmods <- regressionBF(y ~ x1 + x2, data = dat, progress = FALSE)
 
     res <- weighted_posteriors(BFmods)
-    testthat::expect_equal(attr(res,"weights")$weights,c(1032, 805, 1388, 775))
+    testthat::expect_equal(attr(res, "weights")$weights, c(1032, 805, 1388, 775))
 
-    wHDI <- hdi(res[c("x1","x2")], ci = 0.9)
+    wHDI <- hdi(res[c("x1", "x2")], ci = 0.9)
     testthat::expect_equal(wHDI$CI_low, c(-0.519, -0.640), tol = 1e-3)
     testthat::expect_equal(wHDI$CI_high, c(0.150, 0.059), tol = 1e-3)
   })
@@ -37,10 +42,12 @@ if (require("BayesFactor", quietly = TRUE)) {
     set.seed(123)
     data(sleep)
 
-    BFS <- ttestBF(x = sleep$extra[sleep$group == 1],
-                   y = sleep$extra[sleep$group == 2],
-                   nullInterval = c(-Inf,0),
-                   paired = TRUE)
+    BFS <- ttestBF(
+      x = sleep$extra[sleep$group == 1],
+      y = sleep$extra[sleep$group == 2],
+      nullInterval = c(-Inf, 0),
+      paired = TRUE
+    )
 
     res <- weighted_posteriors(BFS)
 
@@ -55,13 +62,15 @@ if (.runThisTest) {
       testthat::skip_on_cran()
 
       fit1 <- brm(rating ~ treat + period + carry,
-                  data = inhaler,
-                  refresh = 0,
-                  save_pars = save_pars(all = TRUE))
+        data = inhaler,
+        refresh = 0,
+        save_pars = save_pars(all = TRUE)
+      )
       fit2 <- brm(rating ~ period + carry,
-                  data = inhaler,
-                  refresh = 0,
-                  save_pars = save_pars(all = TRUE))
+        data = inhaler,
+        refresh = 0,
+        save_pars = save_pars(all = TRUE)
+      )
 
 
       set.seed(444)
@@ -83,4 +92,4 @@ if (.runThisTest) {
       # plot(res_BT1)
     })
   }
-}
\ No newline at end of file
+}
